@@ -1,3 +1,8 @@
+from dataclasses import dataclass
+from typing import Dict, Text
+
+import datasets
+
 LANGUAGE_CATALOG_URL = "api/nlu/v1/supported-languages"
 CREATE_EXAMPLE_URL = "api/nlu/v1/single/example"
 CREATE_PROJECT_URL = "api/nlu/v1/project"
@@ -19,6 +24,7 @@ DELETE_MULTIPLE_PROJECT_URL = "api/nlu/v1/project"
 ADD_SYNONYMS_TO_THE_PROJECT_URL = "api/nlu/v1/project/add/synonym"
 LIST_SYNONYMS_IN_THE_PROJECT_URL = "api/nlu/v1/project/list/synonym"
 
+
 TRAINING_PROGRESS = [
     "Initiated",
     "Queued",
@@ -131,3 +137,14 @@ C_TRAINING = "🟠"
 C_FAILED = "🔴"
 C_TIMED_OUT = "🟤"
 C_DEAD = "⚫"
+
+# DEFAULT VALUES
+DEFAULT_RASA_TRAINING_JOBS = 1
+
+
+@dataclass
+class HuggingfaceDatasetCollection:
+    subset: Text
+    ner_dict: Dict
+    train_dataset: datasets.arrow_dataset.Dataset
+    test_dataset: datasets.arrow_dataset.Dataset
